==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebAccordionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebAccordionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebAccordionDescription, _super);
    function WebAccordionDescription() {
        var _this = _super.call(this) || this;
        _this.f = false;
        return _this;
    }
    WebAccordionDescription.prototype.get_type = function () {
        return "WebAccordion";
    };
    Object.defineProperty(WebAccordionDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebAccordionDescription.prototype, "singleExpand", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("SingleExpand");
        },
        enumerable: true,
        configurable: true
    });
    WebAccordionDescription.$t = markType(WebAccordionDescription, 'WebAccordionDescription', Description.$);
    return WebAccordionDescription;
}(Description));
export { WebAccordionDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebAccordionDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebAccordionDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebAccordionDescription, _super);
    function WebAccordionDescription() {
        var _this = _super.call(this) || this;
        _this.h = false;
        _this.m = null;
        _this.l = null;
        _this.k = null;
        _this.j = null;
        return _this;
    }
    WebAccordionDescription.prototype.get_type = function () {
        return "WebAccordion";
    };
    Object.defineProperty(WebAccordionDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebAccordionDescription.prototype, "singleExpand", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("SingleExpand");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebAccordionDescription.prototype, "openingRef", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("OpeningRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebAccordionDescription.prototype, "openedRef", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.g("OpenedRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebAccordionDescription.prototype, "closingRef", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.g("ClosingRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebAccordionDescription.prototype, "closedRef", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("ClosedRef");
        },
        enumerable: false,
        configurable: true
    });
    WebAccordionDescription.$t = markType(WebAccordionDescription, 'WebAccordionDescription', Description.$);
    return WebAccordionDescription;
}(Description));
export { WebAccordionDescription };
